bluemath\_tk.waves package
==========================

Submodules
----------

bluemath\_tk.waves.binwaves module
----------------------------------

.. automodule:: bluemath_tk.waves.binwaves
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.climate module
---------------------------------

.. automodule:: bluemath_tk.waves.climate
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.estela module
--------------------------------

.. automodule:: bluemath_tk.waves.estela
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.greenswell module
------------------------------------

.. automodule:: bluemath_tk.waves.greenswell
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.partitioning module
--------------------------------------

.. automodule:: bluemath_tk.waves.partitioning
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.series module
--------------------------------

.. automodule:: bluemath_tk.waves.series
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.snakes module
--------------------------------

.. automodule:: bluemath_tk.waves.snakes
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.spectra module
---------------------------------

.. automodule:: bluemath_tk.waves.spectra
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.statistics module
------------------------------------

.. automodule:: bluemath_tk.waves.statistics
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.waves.superpoint module
------------------------------------

.. automodule:: bluemath_tk.waves.superpoint
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.waves
   :members:
   :undoc-members:
   :show-inheritance:
